from distutils.core import setup

setup(
    name            = 'nester2018',
    version         = '1.1.0',
    py_modules      = ['nester2018'],
    author          = 'josery',
    author_email    = 'admin@chenxu.info',
    url             = 'http://chenxu.info',
    description     = 'A simple printer of nested lists', 
)
